from setuptools import setup

setup(
    name="mypackage-student-records",
    version="0.12",
    description="Progetto di Produzione del Software",
    author="SMJ",
    author_email="s.madaghiele@campus.unimib.it",
    url="https://gitlab.com/MarcecaManu/2023_assignment1_student_records",
    packages=["src"],
    install_requires=[
        "requirements.txt",
    ],
)
